@@ -11,26 +11,22 @@ from . import K_Component as K_Component
 import copy
 import ast
 
+
+
+
+
+
 class NetComp(object):
     """Main class **NetComp**. Class containing components such as **BorderPoints** or
     **Compressors**, used for the non-OSM data set.
     """
+    
+    
     def __init__(self):
+        Comps=['BorderPoints','Compressors', 'Consumers', 'LNGs','Nodes','PowerPlants','Productions','PipePoints','PipeSegments', 'PipeLines','Storages'] 
         self.SourceName             = ['']
-        self.BorderPoints           = []    # BP
-        self.Compressors            = []    # CO
-        self.ConnectionPoints       = []    # CP
-        self.Consumers              = []    # CS
-        self.EntryPoints            = []    # EP
-        self.InterConnectionPoints  = []    # IC
-        self.LNGs                   = []    # LG
-        self.Nodes                  = []    # NO
-        self.PipePoints             = []    # PP
-        self.PipeSegments           = []    # PS
-        self.PipeLines              = []    # PL
-        self.Productions            = []    # PD
-        self.Storages               = []    # SR
-
+        for comp in Comps:
+            setattr(self,comp,[])
         self.Processes              = []
 
 
@@ -44,40 +40,27 @@ class NetComp(object):
 
         return RetNetz
 
-
-
-
     def AttribLables(self):
         return ['id', 'name', 'source_id', 'node_id', 'lat', 'long', 'country_code', 'comment']
 
-
-
-
     def CompLabelsSpot(self):
-        return ['Compressors', 'Consumers', 'ConnectionPoints', 'InterConnectionPoints',
-                'BorderPoints', 'LNGs', 'Storages', 'EntryPoints', 'Productions', ]
-
-
-
+        return ['Compressors', 'Consumers',
+                'BorderPoints', 'LNGs', 'Storages', 'PowerPlants','Productions' ]
 
     def CompLabelsPipes(self):
         return ['PipeSegments', 'PipeLines']
 
-
-
-
-
     def CompLabelsNoNodes(self):
         return [*self.CompLabelsSpot(), *self.CompLabelsPipes(),
                 'PipePoints']
 
-
-
-
     def CompLabels(self):
         return ['Nodes', *self.CompLabelsNoNodes()]
 
 
+
+
+
     def copy(self):
         """Method to create copy of instance.
         """
@@ -430,25 +413,16 @@ class NetComp(object):
 class NetComp_OSM(NetComp):
     """
     same as NetComp but more elements, [outdated]
-    """
+    """    
+    
+    
     def __init__(self):
+        Comps=['BorderPoints','Compressors', 'Consumers', 'LNGs','Nodes','PowerPlants', 'Productions','PipePoints','PipeSegments', 'PipeLines','Storages'] 
+       
         self.SourceName             = ['']
-        self.BorderPoints           = []    # BP
-        self.Compressors            = []    # CO
-        self.Consumers              = []    # CS
-        self.ConnectionPoints       = []    # CP
-        self.EntryPoints            = []    # EP
-        self.InterConnectionPoints  = []    # IC
-        self.LNGs                   = []    # LG
-        self.Nodes                  = []    # NO
-        self.PipePoints             = []    # PP
-        self.PipeSegments           = []    # PS
-        self.PipeLines              = []    # PL
-        self.Productions            = []    # PD
-        self.Storages               = []    # SR
+        for comp in Comps: 
+           setattr(self,comp,[])
         self.Processes              = []
-
-
     pass
 
 
