@@ -116,7 +116,7 @@ def CountryPolyDict(FileName_Map,predicted_countrycodes = ''):
 #        FileName_Map     = os.path.join(os.getcwd(),'TM_World_Borders/TM_WORLD_BORDERS-0.3.shp')
 
 
-    print(os.path.isfile(FileName_Map))
+    #print(os.path.isfile(FileName_Map))
 
     sf          = shapefile.Reader(FileName_Map, encoding="latin1")
     polygon     = sf.shapes()
