@@ -8,7 +8,8 @@
 #from unidecode                     import unidecode
 #import Code.OSM.C_colors              as CC
 import esy.osmfilter as EO
-from . import M_OSM_convert 
+from . import M_OSM_convert
+from . import OSMpath
 from esy.osmfilter import Node,Way,Relation
 from esy.osmfilter import osm_colors as CC
 
@@ -154,7 +155,9 @@ def read(PBF_inputfile,
                                         CreateCountryCodeForLines=CreateCountryCodeForLines,
                                         LoadCountryCodeForLines=LoadCountryCodeForLines,
                                         min_length=min_length,segment_length=length,verbose=verbose)
-    
+
+
+    OSM=OSMpath.pathcorrection(OSM)
 
     return OSM
 
